% CRP_DEMO1: Simple demo script for crplus.m
%
% In this example, we model a homogeneous portfolio.

% Percentiles to calculate.  
q=[0.95 0.99 0.995 0.9997]';

% When defprob and/or factor loadings do not vary across obligors,
% they can be entered as scalars.
defprob=0.01;     % 1 pct unconditional default probability
w=1;          % assume single systematic factor and no specific risk
sigma=1.5;

% Loans are equal-sized.  Lossvalue is scaled so that
% VaR will be expressed as a percentage of total book value.
% NOTE!! Unlike defprob and w, lossvalue must be entered as a vector
% of length N.  Indeed, crplus checks the length of lossvalue in
% order to determine N!
N=3000;                             % number of obligors
LGD=0.3;                            % loss given default
lossvalue=repmat(100*LGD/N,N,1);    % Nx1 vector

% When lossunit is not specified, crplus will choose one by
% a rule of thumb.  In the case of a portfolio with equal-sized
% loans, it will always choose the (homogeneous) loss exposure 
% as the lossunit value.

[VaR,summarystats,errorcode] ...
  = crplus(defprob,lossvalue,w,sigma,q);
